==> framer-motion-0.3.2.tgz: package/src/events/__tests__/use-event.test.tsx <==
import "../../../jest.setup"
import { fireEvent, render } from "react-testing-library"
import * as React from "react"
import { useRef, useEffect } from "react"
import { useEvent } from "../"

describe("useEvent", () => {
    it("should handle the ref not being set correctly", () => {
        // TODO maybe show a warning too?
        const handler = jest.fn()
        const Component = () => {
            const ref = useRef(null)
            useEvent("mousedown", ref, handler)
            return <div />
        }
        const { container, rerender } = render(<Component />)
        rerender(<Component />)
        fireEvent.mouseDown(container.firstChild as Element)
        expect(handler).not.toHaveBeenCalled()
    })
    it("should call the handler when the event is fired", () => {
        const handler = jest.fn()
        const Component = () => {
            const ref = useRef(null)
            useEvent("mousedown", ref, handler)
            return <div ref={ref} />
        }
        const { container, rerender } = render(<Component />)
        rerender(<Component />)
        fireEvent.mouseDown(container.firstChild as Element)
        expect(handler).toHaveBeenCalledTimes(1)
    })

    it("should fire an event on another element in the ref", async () => {
        const handler = jest.fn()
        const promise = new Promise(resolve => {
            const Component = () => {
                const ref = useRef(document.body)
                useEvent("mousedown", ref, handler)
                useEffect(resolve)
                return <div />
            }
            const { rerender } = render(<Component />)
            rerender(<Component />)
            fireEvent.mouseDown(document.body)
        })
        await expect(promise).resolves.toEqual(undefined)
        expect(handler).toHaveBeenCalled()
    })
    it("should not fire an event if the component has been unmounted", async () => {
        const handler = jest.fn()
        const promise = new Promise(resolve => {
            const Component = () => {
                const ref = useRef(document.body)
                useEvent("mousedown", ref, handler)
                useEffect(resolve)
                return <div />
            }
            const { rerender, unmount } = render(<Component />)
            rerender(<Component />)
            unmount()
            fireEvent.mouseDown(document.body)
        })
        await expect(promise).resolves.toEqual(undefined)
        expect(handler).not.toHaveBeenCalled()
    })

    describe("when an element is provided", () => {
        const target = window
        it("should return an start and an stop function", () => {
            const handler = jest.fn()
            const capture: { result?: any } = {}
            const Component = () => {
                capture.result = useEvent("mousedown", target, handler)
                return <div />
            }
            render(<Component />)
            const [start, stop] = capture.result
            expect(start).toBeInstanceOf(Function)
            expect(stop).toBeInstanceOf(Function)
        })
        it("should should fire the event handler after the start function is called", () => {
            const handler = jest.fn()
            const capture: { result?: any } = {}
            const Component = () => {
                capture.result = useEvent("mousedown", target, handler)
                return <div />
            }
            render(<Component />)
            const [start] = capture.result
            start()
            fireEvent.mouseDown(document.body)
            expect(handler).toHaveBeenCalledTimes(1)
            fireEvent.mouseDown(document.body)
            expect(handler).toHaveBeenCalledTimes(2)
        })
        it("should should not fire the event handler before the start function is called", () => {
            const handler = jest.fn()
            const Component = () => {
                useEvent("mousedown", target, handler)
                return <div />
            }
            render(<Component />)
            fireEvent.mouseDown(document.body)
            expect(handler).not.toHaveBeenCalled()
        })
        it("should should stop firing the event handler after the stop function is called", () => {
            const handler = jest.fn()
            const capture: { result?: any } = {}
            const Component = () => {
                capture.result = useEvent("mousedown", target, handler)
                return <div />
            }
            render(<Component />)
            const [start, stop] = capture.result
            start()
            fireEvent.mouseDown(document.body)
            expect(handler).toHaveBeenCalledTimes(1)
            stop()
            fireEvent.mouseDown(document.body)
            expect(handler).toHaveBeenCalledTimes(1)
        })
        it("should return undefined when no handler is provided", () => {
            const capture: { result?: any } = { result: "bla" }
            const Component = () => {
                capture.result = useEvent("mousedown", target)
                return <div />
            }
            render(<Component />)
            expect(capture.result).toBe(undefined)
        })
    })

    describe("in non-browser environments", () => {
        // In server side some rendering environments window can be undefined
        it("should return an start and an stop function when no target is provided", () => {
            const handler = jest.fn()
            const capture: { result?: any } = {}
            const Component = () => {
                capture.result = useEvent("mousedown", undefined, handler)
                return <div />
            }
            render(<Component />)
            const [start, stop] = capture.result
            expect(start).toBeInstanceOf(Function)
            expect(stop).toBeInstanceOf(Function)
            expect(() => start()).not.toThrow()
            expect(() => stop()).not.toThrow()
        })
        it("should return an start and an stop function when a mocked window is provided", () => {
            const handler = jest.fn()
            const capture: { result?: any } = {}
            const Component = () => {
                capture.result = useEvent("mousedown", window, handler)
                return <div />
            }
            render(<Component />)
            const [start, stop] = capture.result
            expect(start).toBeInstanceOf(Function)
            expect(stop).toBeInstanceOf(Function)
        })
    })
})

==> framer-motion-3.1.3.tgz: package/src/events/__tests__/use-event.test.tsx <==
import { render } from "../../../jest.setup"
import { fireEvent } from "@testing-library/react"
import * as React from "react"
import { useRef, useEffect } from "react"
import { useDomEvent } from "../use-dom-event"

describe("useDomEvent", () => {
    it("should handle the ref not being set correctly", () => {
        // TODO maybe show a warning too?
        const handler = jest.fn()
        const Component = () => {
            const ref = useRef(null)
            useDomEvent(ref, "mousedown", handler)
            return <div />
        }
        const { container, rerender } = render(<Component />)
        rerender(<Component />)
        fireEvent.mouseDown(container.firstChild as Element)
        expect(handler).not.toHaveBeenCalled()
    })
    it("should call the handler when the event is fired", () => {
        const handler = jest.fn()
        const Component = () => {
            const ref = useRef(null)
            useDomEvent(ref, "mousedown", handler)
            return <div ref={ref} />
        }
        const { container, rerender } = render(<Component />)
        rerender(<Component />)
        fireEvent.mouseDown(container.firstChild as Element)
        expect(handler).toHaveBeenCalledTimes(1)
    })

    it("should fire an event on another element in the ref", async () => {
        const handler = jest.fn()
        const promise = new Promise(resolve => {
            const Component = () => {
                const ref = useRef(document.body)
                useDomEvent(ref, "mousedown", handler)
                useEffect(resolve)
                return <div />
            }
            const { rerender } = render(<Component />)
            rerender(<Component />)
            fireEvent.mouseDown(document.body)
        })
        await expect(promise).resolves.toEqual(undefined)
        expect(handler).toHaveBeenCalled()
    })
    it("should not fire an event if the component has been unmounted", async () => {
        const handler = jest.fn()
        const promise = new Promise(resolve => {
            const Component = () => {
                const ref = useRef(document.body)
                useDomEvent(ref, "mousedown", handler)
                return <div />
            }
            const { rerender, unmount } = render(<Component />)
            rerender(<Component />)
            unmount()
            requestAnimationFrame(() => {
                fireEvent.mouseDown(document.body)
                resolve()
            })
        })
        await expect(promise).resolves.toEqual(undefined)
        expect(handler).not.toHaveBeenCalled()
    })
})
